//cd C:\Dropbox\E\Consumption\Data\
//cd U:\tf\Matteo\Consumption_2\Data\

window manage close graph _all
// ssc install estout

use state_data19.dta, clear





set more off

//----------------------------------------------------
//Collapse to yearly
preserve
bysort state: keep if _n==1
keep statename state statelong
save output/temp_statename.dta, replace
restore

replace yearnum = year(dofq(year))
replace quarternum = quarter(dofq(year))




* MATTEO REPLACE SUM WITH "MEAN"
collapse (last) year quarternum lfpr frcr ur hp_inc_refis hp_exc_refis ///
	gdpdef quarter time dumevenyear numemp ///
	hpfhfa empl* total_debt mortgage_debt auto_debt creditcard_debt  ///
	polk1_yr polk2_yr polk12_yr polk13_yr polk17_yr hmda* ///
	(mean) retsales retsmoodys retautomoodys moodys_polk1_sa polk1_sa polk2_sa polk12_sa ///
	polk13_sa polk17_sa polk1 polk2 polk12 polk13 polk17 pinc epasaltersa disp_inc usgdpc96 ///
	(sum) xecddsm xehddsm, by(yearnum state) fast

merge m:1 state using output/temp_statename.dta, nogen

drop year
gen year = yearnum
order year

sort statename year 

foreach var of varlist retsmoodys retautomoodys moodys_polk1_sa polk1_sa polk2_sa polk12_sa ///
	polk13_sa polk17_sa polk1 polk2 polk12 polk13 polk17 {
	replace `var' = . if `var'==0
}
//----------------------------------------------------





xtset state year



local basedate_q = "2005"
local n_big_state = 16

global k=1
global minhp=0
global maxhp=100
global maxhp2=35
global maxdy=100
global maxdy2=20
* macro dir (to list all globals)



bysort state (year): gen dur=ur-ur[_n-$k]

gen byte basedate2 = 1 if year==2005

bysort state (year): gen hpreal1=hp_inc_refis/gdpdef
bysort state (year): gen hpreal2=hpfhfa/gdpdef

bysort state (year): gen dhp=100*(hpreal1/hpreal1[_n-$k]-1)
bysort state (year): gen dhplag=dhp[_n-$k]
bysort state (year): gen dhplagsq=dhplag^2/100
bysort state (year): gen dhplagcub=dhplag^3/10000
label variable dhplag `"Lagged one-year % change in House Prices"'


* EMP1: TOTAL NONFARM EMPLOYMENT
bysort state (year): gen emp1=(empl0000)
bysort state (year): gen demp1=100*(emp1/emp1[_n-$k]-1)

* EMP2: TOTAL GOODS
bysort state (year): gen emp2=(empl1000+empl2000+empl3000)
bysort state (year): gen demp2=100*(emp2/emp2[_n-$k]-1)

* EMP3: TOTAL NON-TRADEABLE SERVICES 
egen emp3=rowtotal(empl4300 empl5000 empl5500 empl6000 empl6500 empl7000 empl8000), missing
bysort state (year): gen demp3=100*(emp3/emp3[_n-$k]-1)

* EMP4: emp3 ADDING RETAIL TRADE
egen emp4=rowtotal(empl4200 empl4300 empl5000 empl5500 empl6000 empl6500 empl7000 empl8000), missing
bysort state (year): gen demp4=100*(emp4/emp4[_n-$k]-1)

* EMP5: emp3 ADDING RETAIL TRADE BUT WITHOUT FINANCE AND INSURANCE
egen emp5=rowtotal(empl4200 empl4300 empl5000 empl5553 empl6000 empl6500 empl7000 empl8000), missing
bysort state (year): gen demp5=100*(emp5/emp5[_n-$k]-1)

* emp6: MANUFACTURING
bysort state (year): gen emp6=(empl3000)
bysort state (year): gen demp6=100*(emp6/emp6[_n-$k]-1)

* CON1: TOTAL RETAIL SALES AEJ
bysort state (year): gen rs1=retsales/gdpdef
bysort state (year): gen drs1=100*(rs1/rs1[_n-$k]-1)

* CON2: TOTAL RETAIL SALES MOODYS
bysort state (year): gen rs2=retsmoodys/gdpdef
bysort state (year): gen drs2=100*(rs2/rs2[_n-$k]-1)

* CON3: AUTO SALES MOODYS
bysort state (year): gen rs3=retautomoodys/gdpdef
bysort state (year): gen drs3=100*(rs3/rs3[_n-$k]-1)

* CON4: AUTO REGISTRATION POLKS via MOODYS
bysort state (year): gen rs4=moodys_polk1_sa
bysort state (year): gen drs4=100*(rs4/rs4[_n-$k]-1)

* CON5: ELECTRICITY
bysort state (year): gen rs5=epasaltersa/gdpdef
bysort state (year): gen drs5=100*(rs5/rs5[_n-$k]-1)

* MO1: HMDA $ volume of originations
bysort state (year): gen mo1=hmda/gdpdef
bysort state (year): gen dmo1=100*(mo1/mo1[_n-$k]-1)

* MO2: HMDA # of originations
bysort state (year): gen mo2=hmda_n
bysort state (year): gen logmo2=log(mo2)
bysort state (year): gen dmo2=100*(mo2/mo2[_n-$k]-1)

* POLK
bysort state (year): gen dpolk2=100*(polk2_sa/polk2_sa[_n-$k]-1)
bysort state (year): gen dpolk1=100*(polk1_sa/polk1_sa[_n-$k]-1)

* US GDP
bysort state (year): gen dusgdp=100*(usgdpc96/usgdpc96[_n-$k]-1)


bysort state (year): gen heatday_1=xehddsm/100
bysort state (year): gen coolday_1=xecddsm/100



* PERSONAL INCOME
* disp_inc
bysort state (year): gen pincx=disp_inc/gdpdef
bysort state (year): gen dpinc=100*(pincx/pincx[_n-$k]-1)
bysort state (year): gen dpinclag=dpinc[_n-$k]


* POLK AUTO DATA
gen byte basedate = 1 if year==`basedate_q'
foreach regis of varlist polk* {
	bysort state (basedate): gen `regis'_index = 100*`regis'/`regis'[1]
}












* Create big state dummy
bysort state (year): egen pincmean=mean(pinc)
sort pincmean
egen bigstate_desc = group(pincmean state)
egen bigstate_max = max(bigstate_desc)
gen bigstate = bigstate_max - bigstate_desc + 1
drop bigstate_desc bigstate_max
sort state year

* Create big housing boom state 
bysort state (year): gen hpend=(hpreal1) if yearnum==2010
bysort state (year): egen hpmean=mean(hpend)
sort hpmean
egen bigstate_desc2 = group(hpmean state)
egen bigstate_max2 = max(bigstate_desc2)
gen bigstate2 = bigstate_max2 - bigstate_desc2 + 1
drop bigstate_desc2 bigstate_max2
sort state year


* MATTEO: REPLACE TIME WITH YEAR
gen byte baseyear = 1 if year==2005
bysort state (baseyear) : gen rs1_index = 100 * rs1 / rs1[1] 
bysort state (baseyear) : gen rs2_index = 100 * rs2 / rs2[1] 
bysort state (baseyear) : gen rs3_index = 100 * rs3 / rs3[1] 
bysort state (baseyear) : gen rs4_index = 100 * rs4 / rs4[1] 
bysort state (baseyear) : gen rs5_index = 100 * rs5 / rs5[1] 
bysort state (baseyear) : gen mo1_index = 100 * mo1 / mo1[1] 
bysort state (baseyear) : gen mo2_index = 100 * mo2 / mo2[1] 
bysort state (baseyear) : gen emp1_index = 100 * emp1 / emp1[1] 
bysort state (baseyear) : gen emp2_index = 100 * emp2 / emp2[1] 
bysort state (baseyear) : gen emp3_index = 100 * emp3 / emp3[1] 
bysort state (baseyear) : gen emp4_index = 100 * emp4 / emp4[1] 
bysort state (baseyear) : gen emp5_index = 100 * emp5 / emp5[1] 
bysort state (baseyear) : gen emp6_index = 100 * emp6 / emp6[1] 
bysort state (baseyear): gen hpreal1_index=hpreal1/hpreal1[1]*100
bysort state (baseyear): gen hpreal2_index=hpreal2/hpreal2[1]*100




* Label variables
label variable rs1_index "Ret.Sales Abdallah (rs1)"
label variable rs2_index "Ret.Sales Moodys (rs2)"
label variable rs3_index "Auto Sales Moodys (rs3)"
label variable rs4_index "Auto Registrations Polk via Moody (rs4)"
label variable rs5_index "Electricity (rs5)"

label variable mo1_index "Mortgage originations $ (mo1)"
label variable mo2_index "Mortgage originations # (mo2)"

label variable drs1 "Retail Sales AL, % growth"
label variable drs2 "Retail Sales Moodys, % growth"
label variable drs3 "Auto Sales Moodys, % growth"
label variable drs4 "Registr. Polk~Moody, % growth"
label variable drs5 "Electricity Res.Sales MWATT, % growth"
label variable dpolk1 "Registr. Polk, % growth"
label variable dpolk2 "Registr. Polk, % growth"

label variable hpreal1_index "House Prices"

label variable emp3_index "Employment"
label variable demp3 "Employment, annual growth"

label variable polk2_sa_index "Auto Regis. POLK"


// 1 - Do the chart for emp3_index rs3_index rs5_index mo1_index hpreal1_index
// 2 - Group states by size or by census region and overlay states belonging to the same region
// 3 - Remove cyan border
// 4 - Allow shading of NBER recessions



gen census_division = ""
replace census_division = "New England" if statename=="ME" | statename=="NH" | statename=="CT" | ///
	statename=="RI" | statename=="VT" | statename=="MA"
replace census_division = "Middle Atlantic" if statename=="NY" | statename=="NJ" | statename=="PA"

replace census_division = "East North Central" if statename=="OH" | statename=="IN" | statename=="IL" | ///
	statename=="MI" | statename=="WI"
replace census_division = "West North Central" if statename=="MN" | statename=="IA" | statename=="MO" | ///
	statename=="ND" | statename=="SD" | statename=="NE" | statename=="KS"
replace census_division = "South Atlantic" if statename=="DE" | statename=="MD" | statename=="DC" | ///
	statename=="VA" | statename=="WV" | statename=="NC" | statename=="SC" | statename=="GA" | statename=="FL"
replace census_division = "East South Central" if statename=="KY" | statename=="TN" | statename=="AL" | ///
	statename=="MS"
replace census_division = "West South Central" if statename=="AR" | statename=="LA" | statename=="OK" | ///
	statename=="TX"
replace census_division = "Mountain" if statename=="MT" | statename=="ID" | statename=="WY" | ///
	statename=="CO" | statename=="NM" | statename=="AZ" | statename=="UT" | statename=="NV"
replace census_division = "Pacific" if statename=="WA" | statename=="OR" | statename=="CA" | ///
	statename=="AK" | statename=="HI"


egen census = group(census_division)







sort state year


************************************************************
* Option 1: House Prices separate positive and negative changes
************************************************************

bysort state (year): gen dhplagpos1=max(dhplag,0) if dhp!=.
bysort state (year): gen dhplagneg1=min(dhplag,0) if dhp!=.
/**/


************************************************************
* Option 2: House Prices separate values above and below linear trend by state
************************************************************

gen loghpreal=log(hpreal1)
gen hpresid=.
levelsof state, local(groups)

foreach a of local groups {
	quietly reg loghpreal time if state==`a'
	tempvar d
	quietly predict `d', residuals
	quietly replace hpresid=`d' if state==`a'
}

bysort state (year): gen dhplagpos2=dhplag if dhp!=.
bysort state (year): gen dhplagneg2=dhplag if dhp!=.
replace dhplagpos2=0 if hpresid<0 & hpresid!=.
replace dhplagneg2=0 if hpresid>=0 & hpresid!=.





************************************************************
* Option 3: x year growth
************************************************************

bysort state (year): gen cv=log(hpreal1)-log(pincx)

bysort state (year): gen dhptrend=100*(cv-cv[_n-3])

bysort state (year): gen dhplagpos3=dhplag if dhp!=.
bysort state (year): gen dhplagneg3=dhplag if dhp!=.
replace dhplagpos3=0 if dhptrend<0 
replace dhplagneg3=0 if dhptrend>=0 










//Percent of states with positive house price variables
bysort year: egen pos_count1 = sum(dhplagpos1!=0 & dhplagpos1!=.)
bysort year: egen neg_count1 = sum(dhplagneg1!=0 & dhplagneg1!=.)
gen percent_pos1 = 100*pos_count1/(pos_count1+neg_count1)

bysort year: egen pos_count2 = sum(dhplagpos2!=0 & dhplagpos2!=.)
bysort year: egen neg_count2 = sum(dhplagneg2!=0 & dhplagneg2!=.)
gen percent_pos2 = 100*pos_count2/(pos_count2+neg_count2)

bysort year: egen pos_count3 = sum(dhplagpos3!=0 & dhplagpos3!=.)
bysort year: egen neg_count3 = sum(dhplagneg3!=0 & dhplagneg3!=.)
gen percent_pos3 = 100*pos_count3/(pos_count3+neg_count3)

sort state year








//Yearly (q4) dummies
local y_start = 1990
local y_end = 2011
forvalues yy = `y_start'(1)`y_end' {
	gen y_`yy' = 0
	replace y_`yy' = 1 if year==`yy'
	local ydummies = "`ydummies' y_`yy'" 
	}


estpost summarize dhp drs1 drs3 drs5 demp1 demp2 demp3 demp4 demp5 demp6 dpinc dmo2
estimates store v
estout v using "output/data_summary_table.csv", cells("mean(fmt(%8.1f)) sd min max") del(",") replace


//Variable summary by state
//estpost tabstat dy, by(statelong) statistics(mean sd min max) columns(statistics)
//estpost correlate dy dylag, by(statelong) 
//estimates store s
//estout s using "state_table_`curr_lhs'.csv", cells("mean(fmt(%8.1f)) sd min max") del(",") replace



/*
keep state yearnum demp4 drs3 drs5 dmo1 dhp
reshape wide demp4 drs3 drs5 dmo1 dhp, i(year) j(state)
pca dhp*  if year>=1990
pca demp4* if year>1990
pca drs3* if year>1990
pca drs5* if year>1990
pca dmo1* if year>1990
pca dhp*  if year>1990
*/






* foreach curr_lhs of varlist demp1 demp2 demp3 demp4 demp5 demp6 drs3 drs5 dmo2 drs1 drs2 {

 foreach curr_lhs of varlist demp4 drs3 drs5 dmo1  {

* foreach curr_lhs of varlist drs4 {


foreach tin1 in "1990" {

*foreach ii in 1 1001 2 2001 3 3001 {
foreach ii in 1 1001 2 2001 {

if `ii'==1 { 
local dhplagpos = "dhplagpos1"
local dhplagneg = "dhplagneg1" 
}
if `ii'==1001 { 
local dhplagpos = "dhplag"
local dhplagneg = "dhplagneg1" 
}
if `ii'==2 { 
local dhplagpos = "dhplagpos2"
local dhplagneg = "dhplagneg2" 
}
if `ii'==2001 { 
local dhplagpos = "dhplag"
local dhplagneg = "dhplagneg2" 
}
if `ii'==3 { 
local dhplagpos = "dhplagpos3"
local dhplagneg = "dhplagneg3" 
}
if `ii'==3001 { 
local dhplagpos = "dhplag"
local dhplagneg = "dhplagneg3" 
}


bysort state (year): gen dy=`curr_lhs' 
*if statelong!="Louisiana"

*drop if statelong=="Oklahoma"

bysort state (year): gen dylag=dy[_n-$k]


local tin2="2011"


if "`curr_lhs'" != "drs5" { 
#delimit ;
xtreg dy dhplag if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m1

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m2

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' `ydummies' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m3

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' dylag `ydummies' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m4

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' dylag dpinclag `ydummies' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m5 
}

else {
#delimit ;
xtreg dy dhplag heatday_1 coolday_1 if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m1

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' heatday_1 coolday_1 if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m2

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' heatday_1 coolday_1 `ydummies' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m3

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' dylag heatday_1 coolday_1 `ydummies' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m4

#delimit ;
xtreg dy `dhplagpos' `dhplagneg' dylag dpinclag heatday_1 coolday_1 `ydummies' if quarter==4  & tin(`tin1',`tin2'), fe robust;
#delimit cr
estimates store m5 
}



if `ii'<100 { 
estout m1 m2 m3 m4 m5 using "output/state_`curr_lhs'_`ii'.csv", drop(*y_*) cells(b(s fmt(%8.2f)) se(par)) stats(N N_g r2_o r2_w r2_b) delimiter(",") starlevel(* 0.10 ** 0.05 *** 0.01) replace
}
if `ii'>=101 { 
estout m1 m2 m3 m4 m5 using "output/state_pval_`curr_lhs'_`ii'.csv", keep(*dhplagneg*) cells(b(s fmt(%8.4f)) p) delimiter(",") starlevel(* 0.10 ** 0.05 *** 0.01) replace
}


// //Variable summary by state
// estpost tabstat dy, by(statelong) statistics(mean sd min max) columns(statistics)
// estimates store s
// estout s using "output/state_table_`curr_lhs'.csv", cells("mean(fmt(%8.1f)) sd min max") del(",") replace

drop dy* 

}

}

}



//-------------------------------
//Summary table for variable list
//-------------------------------

// estpost summarize dhp drs1 drs3 drs5 demp1 demp2 demp3 demp4 demp5 demp6 dpinc dmo2
// estimates store v
// estout v using "data_summary_table.csv", cells("mean(fmt(%8.1f)) sd min max") del(",") replace






//---------------------
// General graphs
//---------------------






label variable percent_pos1 "House Price inflation>0"
label variable percent_pos2 "Above lin.trend (BENCHMARK)"
label variable percent_pos3 "Above lag.house pr./income"
twoway (tsline percent_pos1 percent_pos2 percent_pos3, lwidth(medthick)) if bigstate==1, ytitle( . )  title(Percentage of U.S. states with Housing Boom)  subtitle( ) caption( ) note( ) legend() graphregion(color(white))

label variable percent_pos2 "%, Above linear trend"
twoway (tsline percent_pos2, lwidth(medthick)) if bigstate==1 & tin(1990,2011), ytitle( . )  title(Percentage of U.S. states with Housing Boom)  subtitle( ) caption( ) note( ) graphregion(color(white))





#delimit ; 
graph twoway line rs4_index polk2_sa_index  year if bigstate<=51 & tin(1990,2011), by(statename) 
name(graphpolk, replace) ;
#delimit cr






reg demp3 dhplagpos1 dhplagneg1 if tin(2005,2005) | tin(2008,2008) & abs(dhplag)<$maxhp 
predict dyhat if e(sample)
drop if abs(dhplag)>$maxhp
sort dyhat

#delimit ; 
scatter   demp3 dhplag if tin(2005,2005) & abs(dhplag)<$maxhp2,  mlabel(state) mcolor(green) xsc(r(-20 40)) xlabel(-20 0 20 40)
||scatter demp3 dhplag if tin(2008,2008) & abs(dhplag)<$maxhp2,  mlabel(state) mcolor(red) graphregion(color(white)) xsc(r(-20 40)) xlabel(-20 0 20 40)
|| line dyhat dhplag if abs(dhplag)<$maxhp2, mcolor(black) xsc(r(-20 40)) xlabel(-20 0 20 40)
title(House Prices and Employment, size(medsmall))
ytitle(% Change in Employment)
name(graphA, replace)
legend(off);
*legend(cols(3)) legend(label(1 "2005")  label(2 "2008") label(3 "Fitted"));
#delimit cr




preserve
keep if statelong=="Louisiana"
save output/temp_la_data.dta, replace
restore

drop if statelong=="Louisiana"
reg drs3 dhplagpos1 dhplagneg1 if tin(2005,2005) | tin(2008,2008) & abs(dhplag)<$maxhp
predict dyhat2 if e(sample)
drop if abs(dhplag)>50
sort dyhat2

#delimit ; 
scatter   drs3 dhplag if tin(2005,2005) & abs(dhplag)<$maxhp,  mlabel(state) mcolor(green) 
||scatter drs3 dhplag if tin(2008,2008) & abs(dhplag)<$maxhp,  mlabel(state) mcolor(red)  graphregion(color(white))
|| line dyhat2 dhplag if abs(dhplag)<$maxhp2, mcolor(black) xsc(r(-20 40)) xlabel(-20 0 20 40)
title(House Prices and Auto Sales, size(medsmall))
ytitle(% Change in Auto)
name(graphB, replace)
legend(off);
*legend(cols(3)) legend(label(1 "2005")  label(2 "2008") label(3 "Fitted"));
#delimit cr


append using output/temp_la_data.dta

reg drs5 dhplagpos1 dhplagneg1 if tin(2005,2005) | tin(2008,2008) & abs(dhplag)<$maxhp 
predict dyhat3 if e(sample)
drop if abs(dhplag)>50
sort dyhat3

#delimit ; 
scatter   drs5 dhplag if tin(2005,2005) & abs(dhplag)<$maxhp,  mlabel(state) mcolor(green) 
||scatter drs5 dhplag if tin(2008,2008) & abs(dhplag)<$maxhp,  mlabel(state) mcolor(red)  graphregion(color(white))
|| line dyhat3 dhplag if abs(dhplag)<$maxhp2, mcolor(black) xsc(r(-20 40)) xlabel(-20 0 20 40)
title(House Prices and Electricity, size(medsmall))
ytitle(% Change in Electricity)
name(graphC, replace) 
legend(cols(3)) legend(label(1 "2005")  label(2 "2008") label(3 "Fitted"));
#delimit cr


reg dmo2 dhplagpos1 dhplagneg1 if tin(2005,2005) | tin(2008,2008) & abs(dhplag)<$maxhp 
predict dyhat4 if e(sample)
drop if abs(dhplag)>50
sort dyhat2

#delimit ; 
scatter   dmo2 dhplag if tin(2005,2005) & abs(dhplag)<$maxhp,  mlabel(state) mcolor(green) 
||scatter dmo2 dhplag if tin(2008,2008) & abs(dhplag)<$maxhp,  mlabel(state) mcolor(red)  graphregion(color(white))
|| line dyhat4 dhplag if abs(dhplag)<$maxhp2, mcolor(black) xsc(r(-20 40)) xlabel(-20 0 20 40)
title(House Prices and Mortgage Originations, size(medsmall))
ytitle(% Change in Originations)
name(graphD, replace) 
legend(cols(3)) legend(label(1 "2005")  label(2 "2008") label(3 "Fitted"));
#delimit cr




graph combine graphA graphB graphC graphD, cols(2) graphregion(color(white))




//
//
// #delimit ; 
// xtline hpreal1_index if bigstate<=16, xlabel(#3, labsize(small)) ylabel(#3, labsize(small))  mcolor(black) byopts(rescale) 
// name(graph7, replace) ;
// #delimit cr
//
//
//
// #delimit ;  
// xtline rs3_index rs4_index polk2_sa_index if bigstate<=16, cmissing(n) xlabel(#3, labsize(small)) ylabel(#3, labsize(small))  mcolor(black) byopts(rescale)
// name(graph8, replace) ;
// #delimit cr
//
// twoway (tsline drs3 drs4 dpolk2, lwidth(medthick)) if tin(1990,2011) & bigstate<10, by(state) ytitle( . ) title( )  subtitle( ) caption( ) note( ) legend() graphregion(color(white))
//
